==> aws-java-sdk-1.3.4-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/DecisionTaskScheduledEventAttributesJsonUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import org.codehaus.jackson.JsonToken;
import static org.codehaus.jackson.JsonToken.*;

/**
 * Decision Task Scheduled Event Attributes JSON Unmarshaller
 */
public class DecisionTaskScheduledEventAttributesJsonUnmarshaller implements Unmarshaller<DecisionTaskScheduledEventAttributes, JsonUnmarshallerContext> {

    

    public DecisionTaskScheduledEventAttributes unmarshall(JsonUnmarshallerContext context) throws Exception {
        DecisionTaskScheduledEventAttributes decisionTaskScheduledEventAttributes = new DecisionTaskScheduledEventAttributes();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();

        while (true) {
            if (token == null) return decisionTaskScheduledEventAttributes;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("taskList", targetDepth)) {
                    context.nextToken();
                    decisionTaskScheduledEventAttributes.setTaskList(TaskListJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("startToCloseTimeout", targetDepth)) {
                    context.nextToken();
                    decisionTaskScheduledEventAttributes.setStartToCloseTimeout(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getCurrentDepth() <= originalDepth) {
                    return decisionTaskScheduledEventAttributes;
                }
            }
            token = context.nextToken();
        }
    }

    private static DecisionTaskScheduledEventAttributesJsonUnmarshaller instance;
    public static DecisionTaskScheduledEventAttributesJsonUnmarshaller getInstance() {
        if (instance == null) instance = new DecisionTaskScheduledEventAttributesJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.3.7-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/DecisionTaskScheduledEventAttributesJsonUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import org.codehaus.jackson.JsonToken;
import static org.codehaus.jackson.JsonToken.*;

/**
 * Decision Task Scheduled Event Attributes JSON Unmarshaller
 */
public class DecisionTaskScheduledEventAttributesJsonUnmarshaller implements Unmarshaller<DecisionTaskScheduledEventAttributes, JsonUnmarshallerContext> {

    

    public DecisionTaskScheduledEventAttributes unmarshall(JsonUnmarshallerContext context) throws Exception {
        DecisionTaskScheduledEventAttributes decisionTaskScheduledEventAttributes = new DecisionTaskScheduledEventAttributes();

        
        
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("taskList", targetDepth)) {
                    context.nextToken();
                    decisionTaskScheduledEventAttributes.setTaskList(TaskListJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("startToCloseTimeout", targetDepth)) {
                    context.nextToken();
                    decisionTaskScheduledEventAttributes.setStartToCloseTimeout(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getCurrentDepth() <= originalDepth) break;
            }
            token = context.nextToken();
        }
        
        return decisionTaskScheduledEventAttributes;
    }

    private static DecisionTaskScheduledEventAttributesJsonUnmarshaller instance;
    public static DecisionTaskScheduledEventAttributesJsonUnmarshaller getInstance() {
        if (instance == null) instance = new DecisionTaskScheduledEventAttributesJsonUnmarshaller();
        return instance;
    }
}
